@@ -96,7 +96,9 @@ public final class DavGateway {
                 public void run() {
                     DavGatewayTray.debug(new BundleMessage("LOG_GATEWAY_INTERRUPTED"));
                     DavGateway.stop();
-                    LOCK.notifyAll();
+                    synchronized (LOCK) {
+                        LOCK.notifyAll();
+                    }
                 }
             });
 
@@ -165,7 +167,7 @@ public final class DavGateway {
             @Override
             public void run() {
                 String releasedVersion = getReleasedVersion();
-                if (currentVersion.length() > 0 && releasedVersion != null && currentVersion.compareTo(releasedVersion) < 0) {
+                if (!currentVersion.isEmpty() && releasedVersion != null && currentVersion.compareTo(releasedVersion) < 0) {
                     DavGatewayTray.info(new BundleMessage("LOG_NEW_VERSION_AVAILABLE", releasedVersion));
                 }
 
